==> dyte_client-0.6.0.tar.gz: ios/Classes/DyteMeetingPlugin.m <==
//
//  DyteMeetingPlugin.m
//  dyte_client
//
//  Created by Rohit Bhatia on 7/12/21.
//

#import "DyteMeetingPlugin.h"
#import <Flutter/Flutter.h>
#import <UIKit/UIKit.h>
#import "FLNativeViewFactory.h"
#import "FLNativeView.h"

@import DyteSdk;


static NSString *const CHANNEL_NAME = @"dyte_client";

@interface DyteMeetingPlugin ()
@property(nonatomic, retain) FlutterMethodChannel *channel;

@end

DyteMeetingView *_view;

@implementation DyteMeetingPlugin {
}



//
+ (void)registerWithRegistrar:(nonnull NSObject<FlutterPluginRegistrar> *)registrar {

    FlutterMethodChannel *channel =
         [FlutterMethodChannel methodChannelWithName:CHANNEL_NAME
                                     binaryMessenger:[registrar messenger]];
    _view = [DyteMeetingView new];
    FLNativeViewFactory* factory =
    [[FLNativeViewFactory alloc] initWithMessenger:registrar.messenger dyteView:_view];
    DyteMeetingPlugin *instance = [[DyteMeetingPlugin alloc] init];
     [registrar addMethodCallDelegate:instance channel:channel];
     [registrar addApplicationDelegate:instance];
    [registrar registerViewFactory:factory withId:@"dyte-meeting-view"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    DyteSelfParticipant *selfPartcipant = [DyteSelfParticipant sharedInstance];
    DyteParticipants *participantsInstance = [DyteParticipants sharedInstance];
    if ([@"getPlatformVersion"  isEqualToString:call.method]) {
        UIDevice* device = UIDevice.currentDevice;
        result(device.systemVersion);
    } else if ([@"getSelf" isEqualToString:call.method]) {
        NSDictionary *selfInfo = @{
            @"id": selfPartcipant.id ? selfPartcipant.id : @"",
            @"name": selfPartcipant.name ? selfPartcipant.name : @"",
            @"picture": selfPartcipant.picture ? selfPartcipant.picture : @"",
            @"audioEnabled": @(selfPartcipant.audioEnabled),
            @"videoEnabled": @(selfPartcipant.videoEnabled),
            @"isPinned": @(selfPartcipant.isPinned)
        };
        result(selfInfo);
    } else if ([@"getMeetingParticipants" isEqualToString:call.method]) {
        result(participantsInstance.participants);
    } else if ([@"selfEnableAudio"isEqualToString:call.method]) {
//        [selfPartcipant enableAudio];
    } else if ([@"selfDisableAudio" isEqualToString:call.method]) {
        [selfPartcipant disableAudio];
    } else if ([@"selfDisableVideo" isEqualToString:call.method]) {
//        [selfPartcipant enableVideo];
    } else if ([@"selfEnableVideo" isEqualToString:call.method]) {
        [selfPartcipant disableVideo];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    }
    else if ([@"updateUIConfig" isEqualToString :call.method]) {
        NSError *error;
        NSString *dictString=[NSString stringWithFormat:@"%@", call.arguments[@"config"]];
            NSData *jsonData = [dictString dataUsingEncoding:NSUTF8StringEncoding];
            NSDictionary *json = [NSJSONSerialization JSONObjectWithData:jsonData
                                                  options:NSJSONReadingMutableContainers
                                                    error:&error];
        [_view updateUiConfig:json];
    }
    else if ([@"leaveRoom"  isEqualToString :call.method]) {
        [selfPartcipant leaveRoom];
    }else {
        NSLog(@"😓 Method not implemented %@", call.method);
        result(FlutterMethodNotImplemented);
    }
}




@end

==> dyte_client-0.6.1.tar.gz: ios/Classes/DyteMeetingPlugin.m <==
//
//  DyteMeetingPlugin.m
//  dyte_client
//
//  Created by Rohit Bhatia on 7/12/21.
//

#import "DyteMeetingPlugin.h"
#import <Flutter/Flutter.h>
#import <UIKit/UIKit.h>
#import "FLNativeViewFactory.h"
#import "FLNativeView.h"

@import DyteSdk;


static NSString *const CHANNEL_NAME = @"dyte_client";

@interface DyteMeetingPlugin ()
@property(nonatomic, retain) FlutterMethodChannel *channel;

@end

DyteMeetingView *_view;

@implementation DyteMeetingPlugin {
}



//
+ (void)registerWithRegistrar:(nonnull NSObject<FlutterPluginRegistrar> *)registrar {

    FlutterMethodChannel *channel =
         [FlutterMethodChannel methodChannelWithName:CHANNEL_NAME
                                     binaryMessenger:[registrar messenger]];
    _view = [DyteMeetingView new];
    FLNativeViewFactory* factory =
    [[FLNativeViewFactory alloc] initWithMessenger:registrar.messenger dyteView:_view];
    DyteMeetingPlugin *instance = [[DyteMeetingPlugin alloc] init];
     [registrar addMethodCallDelegate:instance channel:channel];
     [registrar addApplicationDelegate:instance];
    [registrar registerViewFactory:factory withId:@"dyte-meeting-view"];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    DyteSelfParticipant *selfPartcipant = [DyteSelfParticipant sharedInstance];
    DyteParticipants *participantsInstance = [DyteParticipants sharedInstance];
    if ([@"getPlatformVersion"  isEqualToString:call.method]) {
        UIDevice* device = UIDevice.currentDevice;
        result(device.systemVersion);
    } else if ([@"getSelf" isEqualToString:call.method]) {
        NSDictionary *selfInfo = @{
            @"id": selfPartcipant.id ? selfPartcipant.id : @"",
            @"name": selfPartcipant.name ? selfPartcipant.name : @"",
            @"picture": selfPartcipant.picture ? selfPartcipant.picture : @"",
            @"audioEnabled": @(selfPartcipant.audioEnabled),
            @"videoEnabled": @(selfPartcipant.videoEnabled),
            @"isPinned": @(selfPartcipant.isPinned)
        };
        result(selfInfo);
    } else if ([@"getMeetingParticipants" isEqualToString:call.method]) {
        result(participantsInstance.participants);
    } else if ([@"selfEnableAudio"isEqualToString:call.method]) {
        [selfPartcipant enableAudio];
    } else if ([@"selfDisableAudio" isEqualToString:call.method]) {
        [selfPartcipant disableAudio];
    } else if ([@"selfDisableVideo" isEqualToString:call.method]) {
        [selfPartcipant enableVideo];
    } else if ([@"selfEnableVideo" isEqualToString:call.method]) {
        [selfPartcipant disableVideo];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    } else if ([@"selfPin" isEqualToString :call.method]) {
        [selfPartcipant selfPin];
    }
    else if ([@"updateUIConfig" isEqualToString :call.method]) {
        NSError *error;
        NSString *dictString=[NSString stringWithFormat:@"%@", call.arguments[@"config"]];
            NSData *jsonData = [dictString dataUsingEncoding:NSUTF8StringEncoding];
            NSDictionary *json = [NSJSONSerialization JSONObjectWithData:jsonData
                                                  options:NSJSONReadingMutableContainers
                                                    error:&error];
        [_view updateUiConfig:json];
    }
    else if ([@"leaveRoom"  isEqualToString :call.method]) {
        [selfPartcipant leaveRoom];
    }else {
        NSLog(@"😓 Method not implemented %@", call.method);
        result(FlutterMethodNotImplemented);
    }
}




@end
